@@ -17,6 +17,7 @@ from .connection import (
     AwsAccessRole,
     AwsCrossAccountRole,
     AwsProperties,
+    CloudResourceProperties,
     CloudSpannerProperties,
     CloudSqlCredential,
     CloudSqlProperties,
@@ -33,6 +34,7 @@ __all__ = (
     "AwsAccessRole",
     "AwsCrossAccountRole",
     "AwsProperties",
+    "CloudResourceProperties",
     "CloudSpannerProperties",
     "CloudSqlCredential",
     "CloudSqlProperties",
